@@ -310,9 +310,14 @@ class _JitHelper:
         for arg in args:
             if isinstance(arg, _JitHelper):
                 args_.append(arg.python_model)
+            else:
+                args_.append(arg)
         for k, v in kwargs.items():
             if isinstance(v, _JitHelper):
                 kwargs_.update({k: v.python_model})
+            else:
+                kwargs_.update({k: v})
+
 
         self.python_model = model_class(*args_, **kwargs_)
         self.compiled_model = None
